==> maskinfojp-0.1.0.tar.gz: maskinfojp-0.1.0/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="maskinfo",
    version="0.1.0",
    author="Your Name",
    author_email="your.email@example.com",
    description="A library to mask sensitive information in files and restore it back",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/maskinfo",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Security",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing",
    ],
    python_requires=">=3.7",
    install_requires=[
        "click>=7.0",
        "chardet>=3.0.4",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov",
            "black",
            "flake8",
            "mypy",
        ],
    },
    entry_points={
        "console_scripts": [
            "maskinfo=maskinfo.cli:main",
        ],
    },
    include_package_data=True,
)

==> maskinfojp-0.1.2.tar.gz: maskinfojp-0.1.2/setup.py <==
from setuptools import find_packages, setup

with open("README.md", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="maskinfo",
    version="0.1.0",
    author="Your Name",
    author_email="your.email@example.com",
    description="A library to mask sensitive information in files and restore it back",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/maskinfo",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Security",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing",
    ],
    python_requires=">=3.7",
    install_requires=[
        "click>=7.0",
        "chardet>=3.0.4",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov",
            "black",
            "flake8",
            "mypy",
        ],
    },
    entry_points={
        "console_scripts": [
            "maskinfo=maskinfo.cli:main",
        ],
    },
    include_package_data=True,
)
